#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <QDialog>
#include <QString>

namespace Ui
{
    class SettingsDialog;
}

class SettingsDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SettingsDialog(QWidget *parent = 0);
    ~SettingsDialog();

    void setChannelsFeedUrl(const QString &hello);
    QString getChannelsFeedUrl() const;

    void setShowRecentlyPlayedSongs(bool b);
    bool isShowRecentlyPlayedSongs() const;

protected:
    void changeEvent(QEvent *e);

private:
    Ui::SettingsDialog *ui;

private slots:
    void defaultChannelsFeedUrl();
};

#endif // SETTINGSDIALOG_H
